#global prerel alpha

Summary:	LZMA compression utilities
Name:		xz
Version:	5.2.5
Release:	10.0.cf%{?dist}

# Scripts xz{grep,diff,less,more} and symlinks (copied from gzip) are
# GPLv2+, binaries are Public Domain (linked against LGPL getopt_long but it's
# OK), documentation is Public Domain
License:	GPLv2+ and Public Domain

URL:		http://tukaani.org/xz/
Source0:	http://tukaani.org/xz/xz-%{version}%{?prerel}.tar.xz
Source100:	colorxzgrep.sh
Source101:	colorxzgrep.csh
Patch1:		xz-5.2.5-enable_CET.patch
Patch2:		https://tukaani.org/xz/xzgrep-ZDI-CAN-16587.patch
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-interpreter
BuildRequires:	sed
Requires:	xz-libs%{?_isa} = %{version}-%{release}

# For /usr/libexec/grepconf.sh (RHBZ#1189120)
Requires:	grep >= 2.20-5

%description
XZ Utils are an attempt to make LZMA compression easy to use on free (as in
freedom) operating systems. This is achieved by providing tools and libraries
which are similar to use than the equivalents of the most popular existing
compression algorithms.

LZMA is a general purpose compression algorithm designed by Igor Pavlov as
part of 7-Zip. It provides high compression ratio while keeping the
decompression speed fast.

%package 	libs
Summary:	Libraries for decoding LZMA compression
License:	Public Domain
Obsoletes:	xz-compat-libs < %{version}-%{release}

%description 	libs
Libraries for decoding files compressed with LZMA or XZ utils.

%package	static
Summary:	Statically linked library for decoding LZMA compression
License:	Public Domain

%description	static
Statically linked library for decoding files compressed with LZMA or
XZ utils. Most users should *not* install this.

%package 	devel
Summary:	Devel libraries & headers for liblzma
License:	Public Domain
Requires:	xz-libs%{?_isa} = %{version}-%{release}

%description	devel
Devel libraries and headers for liblzma.

%package 	lzma-compat
Summary:	Older LZMA format compatibility binaries
# Just a set of symlinks to 'xz' + two Public Domain binaries
License:	Public Domain
Requires:	%{name}%{?_isa} = %{version}-%{release}
Obsoletes:	lzma < %{version}
Provides:	lzma = %{version}

%description  lzma-compat
The lzma-compat package contains compatibility links for older
commands that deal with the older LZMA format.

%prep
%setup -q -n %{name}-%{version}%{?prerel}

# Enable CET for i686 (#1910368)
%patch1 -p1

# xzgrep: arbitrary-file-write vulnerability (CVE-2022-1271)
%patch2 -p1

%build
export CFLAGS="%{optflags}"

%if 0%{?fedora} > 28
%ifarch %ix86
# annocheck reports the following message because liblzma uses crc*_x86.S asm code on i686 (#1630650)
# Failures found:
# Hardened: ./usr/lib/liblzma.so.5.2.4: FAIL: Gaps were detected in the annobin coverage.
CFLAGS="$CFLAGS -Wa,--generate-missing-build-notes=yes"
%endif
%endif

%configure
sed -i	-e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
	-e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
	libtool
%{make_build}

%install
%{make_install}

# Remove stuff we don't want packaged
rm -f %{buildroot}%{_libdir}/*.la

# And we'll package the documentation ourselves...
rm -rf %{buildroot}%{_pkgdocdir}

%find_lang xz

# xzgrep colorization
%global profiledir %{_sysconfdir}/profile.d
mkdir -p %{buildroot}%{profiledir}
install -p -m 644 %{SOURCE100} %{buildroot}%{profiledir}
install -p -m 644 %{SOURCE101} %{buildroot}%{profiledir}

%check
LD_LIBRARY_PATH=$PWD/src/liblzma/.libs make check

%ldconfig_scriptlets libs

%files -f xz.lang
%license COPYING*
%doc AUTHORS NEWS README THANKS TODO doc/*.txt
%{_bindir}/unxz
%{_bindir}/xz
%{_bindir}/xzcat
%{_bindir}/xzcmp
%{_bindir}/xzdec
%{_bindir}/xzdiff
%{_bindir}/xzegrep
%{_bindir}/xzfgrep
%{_bindir}/xzgrep
%{_bindir}/xzless
%{_bindir}/xzmore
%{_mandir}/man1/unxz.1*
%{_mandir}/man1/xz.1*
%{_mandir}/man1/xzcat.1*
%{_mandir}/man1/xzcmp.1*
%{_mandir}/man1/xzdec.1*
%{_mandir}/man1/xzdiff.1*
%{_mandir}/man1/xzegrep.1*
%{_mandir}/man1/xzfgrep.1*
%{_mandir}/man1/xzgrep.1*
%{_mandir}/man1/xzless.1*
%{_mandir}/man1/xzmore.1*
%lang(de) %{_mandir}/de/man1/unxz.1*
%lang(de) %{_mandir}/de/man1/xz.1*
%lang(de) %{_mandir}/de/man1/xzcat.1*
%lang(de) %{_mandir}/de/man1/xzcmp.1*
%lang(de) %{_mandir}/de/man1/xzdec.1*
%lang(de) %{_mandir}/de/man1/xzdiff.1*
%lang(de) %{_mandir}/de/man1/xzegrep.1*
%lang(de) %{_mandir}/de/man1/xzfgrep.1*
%lang(de) %{_mandir}/de/man1/xzgrep.1*
%lang(de) %{_mandir}/de/man1/xzless.1*
%lang(de) %{_mandir}/de/man1/xzmore.1*
%{profiledir}/colorxzgrep.csh
%{profiledir}/colorxzgrep.sh

%files libs
%license COPYING
%{_libdir}/liblzma.so.5*

%files static
%license COPYING*
%{_libdir}/liblzma.a

%files devel
%doc doc/examples*/
%{_includedir}/lzma.h
%{_includedir}/lzma/
%{_libdir}/liblzma.so
%{_libdir}/pkgconfig/liblzma.pc

%files lzma-compat
%{_bindir}/lzcat
%{_bindir}/lzcmp
%{_bindir}/lzdiff
%{_bindir}/lzegrep
%{_bindir}/lzfgrep
%{_bindir}/lzgrep
%{_bindir}/lzless
%{_bindir}/lzma
%{_bindir}/lzmadec
%{_bindir}/lzmainfo
%{_bindir}/lzmore
%{_bindir}/unlzma
%{_mandir}/man1/lzcat.1*
%{_mandir}/man1/lzcmp.1*
%{_mandir}/man1/lzdiff.1*
%{_mandir}/man1/lzegrep.1*
%{_mandir}/man1/lzfgrep.1*
%{_mandir}/man1/lzgrep.1*
%{_mandir}/man1/lzless.1*
%{_mandir}/man1/lzma.1*
%{_mandir}/man1/lzmadec.1*
%{_mandir}/man1/lzmainfo.1*
%{_mandir}/man1/lzmore.1*
%{_mandir}/man1/unlzma.1*
%lang(de) %{_mandir}/de/man1/lzcat.1*
%lang(de) %{_mandir}/de/man1/lzcmp.1*
%lang(de) %{_mandir}/de/man1/lzdiff.1*
%lang(de) %{_mandir}/de/man1/lzegrep.1*
%lang(de) %{_mandir}/de/man1/lzfgrep.1*
%lang(de) %{_mandir}/de/man1/lzgrep.1*
%lang(de) %{_mandir}/de/man1/lzless.1*
%lang(de) %{_mandir}/de/man1/lzma.1*
%lang(de) %{_mandir}/de/man1/lzmadec.1*
%lang(de) %{_mandir}/de/man1/lzmore.1*
%lang(de) %{_mandir}/de/man1/unlzma.1*

%changelog
* Sun Jul 24 2022 Paul Howarth <paul@city-fan.org> - 5.2.5-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Apr 18 2022 Paul Howarth <paul@city-fan.org> - 5.2.5-9.0.cf
- xzgrep: Arbitrary-file-write vulnerability (#2073310, CVE-2022-1271)

* Mon Jan 24 2022 Paul Howarth <paul@city-fan.org> - 5.2.5-8.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sun Jul 25 2021 Paul Howarth <paul@city-fan.org> - 5.2.5-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Remove the ancient PPC64 hack

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 5.2.5-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Jan  4 2021 Paul Howarth <paul@city-fan.org> - 5.2.5-4.0.cf
- Enable CET for i686 (#1910368)

* Thu Jul 30 2020 Paul Howarth <paul@city-fan.org> - 5.2.5-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jun 10 2020 Paul Howarth <paul@city-fan.org> - 5.2.5-2.0.cf
- Fix location of German manpages for lzma tools (#1844813)

* Mon Mar 30 2020 Paul Howarth <paul@city-fan.org> - 5.2.5-1.0.cf
- Update to 5.2.5
  liblzma:
  - Fixed several C99/C11 conformance bugs; now the code is clean under
    gcc/clang -fsanitize=undefined (some of these changes might have a negative
    effect on performance with old GCC versions or compilers other than GCC and
    Clang, but the configure option --enable-unsafe-type-punning can be used to
    [mostly] restore the old behaviour but it shouldn't normally be used)
  - Improved API documentation of lzma_properties_decode()
  - Added a very minor encoder speed optimization
  xz:
  - Fixed a crash in "xz -dcfv not_an_xz_file" (all four options were required
    to trigger it); the crash occurred in the progress indicator code when xz
    was in passthru mode where xz works like "cat"
  - Fixed an integer overflow with 32-bit off_t; it could happen when
    decompressing a file that has a long run of zero bytes, which xz would try
    to write as a sparse file - since the build system enables large file
    support by default, off_t is normally 64-bit even on 32-bit systems
  - Fixes for --flush-timeout:
    - Fix semi-busy-waiting
    - Avoid unneeded flushes when no new input has arrived since the previous
      flush was completed
  - Added a special case for 32-bit xz: if --memlimit-compress is used to
    specify a limit that exceeds 4020 MiB, the limit will be set to 4020 MiB
    (the values "0" and "max" aren't affected by this and neither is
    decompression); this hack can be helpful when a 32-bit xz has access to
    4 GiB address space but the specified memlimit exceeds 4 GiB, which can
    happen e.g. with some scripts
  - Capsicum sandbox is now enabled by default where available (FreeBSD ≥ 10);
    the sandbox debug messages (xz -vv) were removed since they seemed to be
    more annoying than useful
  - DOS build now requires DJGPP 2.05 instead of 2.04beta; a workaround for a
    locale problem with DJGPP 2.05 was added
  xzgrep and other scripts:
  - Added a configure option --enable-path-for-scripts=PREFIX; it is disabled
    by default except on Solaris where the default is /usr/xpg4/bin (see
    INSTALL for details)
  - Added a workaround for a POSIX shell detection problem on Solaris
  Build systems:
  - Added preliminary build instructions for z/OS (see INSTALL section 1.2.9)
  - Experimental CMake support was added
    - It should work to build static liblzma on a few operating systems
    - It may or may not work to build shared liblzma
    - On some platforms it can build xz and xzdec too but those are only for
      testing
    - See the comment in the beginning of CMakeLists.txt for details
  - Visual Studio project files were updated
    - WindowsTargetPlatformVersion was removed from VS2017 files and set to
      "10.0" in the added VS2019 files
    - In the future the VS project files will be removed when CMake support is
      good enough
  - New #defines in config.h: HAVE___BUILTIN_ASSUME_ALIGNED,
    HAVE___BUILTIN_BSWAPXX, and TUKLIB_USE_UNSAFE_TYPE_PUNNING
  - autogen.sh has a new optional dependency on po4a and a new option --no-po4a
    to skip that step; this matters only if one wants to remake the build files
    (po4a is used to update the translated man pages but as long as the man
    pages haven't been modified, there's nothing to update and one can use
    --no-po4a to avoid the dependency on po4a)
  Translations:
  - XZ Utils translations are now handled by the Translation Project:
    https://translationproject.org/domain/xz.html
  - All man pages are now included in German too
  - New xz translations: Brazilian Portuguese, Finnish, Hungarian, Chinese
    (simplified), Chinese (traditional), and Danish (partial translation)
  - Updated xz translations: French, German, Italian, and Polish
  - Unfortunately a few new xz translations weren't included due to technical
    problems like too long lines in --help output or misaligned column headings
    in tables; in the future, many of these strings will be split and e.g. the
    table column alignment will be handled in software, which should make the
    strings easier to translate

* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 5.2.4-8.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sat Aug 24 2019 Paul Howarth <paul@city-fan.org> - 5.2.4-7.0.cf
- Rebuilt

* Mon Aug 12 2019 Paul Howarth <paul@city-fan.org> - 5.2.4-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Feb  4 2019 Paul Howarth <paul@city-fan.org> - 5.2.4-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Nov 22 2018 Paul Howarth <paul@city-fan.org> - 5.2.4-4.0.cf
- Fix annocheck failures on i686 (#1630650)

* Sat Jul 21 2018 Paul Howarth <paul@city-fan.org> - 5.2.4-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat May 12 2018 Paul Howarth <paul@city-fan.org> - 5.2.4-2.0.cf
- Update to 5.2.4
  liblzma:
  - Allow 0 as memory usage limit instead of returning LZMA_PROG_ERROR; now 0
    is treated as if 1 byte was specified, which effectively is the same as 0
  - Use "noexcept" keyword instead of "throw()" in the public headers when a
    C++11 (or newer standard) compiler is used
  - Added a portability fix for recent Intel C Compilers
  - Microsoft Visual Studio build files have been moved under windows/vs2013
    and windows/vs2017
  xz:
  - Fix "xz --list --robot missing_or_bad_file.xz", which would try to print an
    uninitialized string and thus produce garbage output; since the exit status
    is non-zero, most uses of such a command won't try to interpret the garbage
    output
  - "xz --list foo.xz" could print "Internal error (bug)" in a corner case
    where a specific memory usage limit had been set
- Switch to %%ldconfig_scriptlets
- Drop ppc64p7 hack, per fedora devel list discussion:
  https://lists.fedoraproject.org/archives/list/
  devel@lists.fedoraproject.org/thread/2OWD2QRDFBEC6HTPVQ7FMJENH32BWT54/
- Don't explicitly set _FILE_OFFSET_BITS; package uses AC_SYS_LARGEFILE

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 5.2.3-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 5.2.3-6.0.cf
- ldconfig scriptlets replaced by RPM File Triggers from Fedora 28

* Sun Sep 17 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-5.0.cf
- Use %%make_build and %%make_install

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Fri Jul 28 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jan  2 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-1.0.cf
- Update to 5.2.3
  - xz:
    - Always close a file before trying to delete it to avoid problems on some
      operating system and file system combinations
    - Fixed copying of file timestamps on Windows
    - Added experimental (disabled by default) sandbox support using Capsicum
      (FreeBSD ≥ 10)
  - C99/C11 conformance fixes to liblzma; the issues affected at least some
    builds using link-time optimizations
  - Fixed bugs in the rarely-used function lzma_index_dup()
  - Use of external SHA-256 code is now disabled by default
  - Changed CPU core count detection to use sched_getaffinity() on GNU/Linux
    and GNU/kFreeBSD
  - Fixes to the build-system and xz to make xz buildable even when encoders,
    decoders, or threading have been disabled from liblzma using configure
    options; these fixes added two new #defines to config.h: HAVE_ENCODERS and
    HAVE_DECODERS

* Tue Aug  2 2016 Paul Howarth <paul@city-fan.org> - 5.2.2-2.1.cf
- Specify build requirements

* Thu Feb 11 2016 Paul Howarth <paul@city-fan.org> - 5.2.2-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Sep 29 2015 Paul Howarth <paul@city-fan.org> - 5.2.2-1.0.cf
- Update to 5.2.2
  - Fixed bugs in QNX-specific code
  - Omitted the use of pipe2() even if it is available to avoid portability
    issues with some old Linux and glibc combinations
  - Updated German translation
  - Added project files to build static and shared liblzma (not the whole XZ
    Utils) with Visual Studio 2013 update 2 or later
  - Documented that threaded decompression hasn't been implemented yet; a
    5.2.0 NEWS entry describing multi-threading support had incorrectly said
    "decompression" when it should have said "compression"
- Remove xz-compat-libs unconditionally
- Explicitly package the documentation ourselves

* Fri Jul 10 2015 Paul Howarth <paul@city-fan.org> - 5.2.1-3.0.cf
- Remove xz-compat-libs (apart from F-22 builds) as it is not necessary
  (#1179193)

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 5.2.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Feb 27 2015 Paul Howarth <paul@city-fan.org> - 5.2.1-1.0.cf
- Update to 5.2.1
  - Fixed a compression-ratio regression in fast mode of LZMA1 and LZMA2; the
    bug is present in 5.1.4beta and 5.2.0 releases
  - Fixed a portability problem in xz that affected at least OpenBSD
  - Fixed xzdiff to be compatible with FreeBSD's mktemp, which differs from
    most other mktemp implementations
  - Changed CPU core count detection to use cpuset_getaffinity() on FreeBSD

* Thu Feb  5 2015 Paul Howarth <paul@city-fan.org> - 5.2.0-2.0.cf
- Depend on grep that contains grepconf.sh (#1189120)
- Use xz-compressed tarball

* Tue Jan  6 2015 Paul Howarth <paul@city-fan.org> - 5.2.0-1.0.cf
- Rebase per upstream release notes (#1023718)
  http://www.mail-archive.com/xz-devel@tukaani.org/msg00216.html
- fedora-review fixes, documentation/license fixes in spec

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-16.1.alpha.cf
- Only attempt colored xz*grep output on Fedora 22 onwards

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-16.alpha.cf
- xz*grep's output is colored iff grep's is (#1034846)

* Wed Aug 20 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-15.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Aug  7 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-14.alpha.cf
- Use %%license where possible

* Fri Jun 13 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-13.alpha.cf
- xzgrep: return 0 when at least one file matches (#1109122)

* Sat Jun  7 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-12.alpha.cf
- Drop ChangeLog; it's big and the excitement is summarised in NEWS

* Fri May 16 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-10.alpha.cf
- Add a -static sub-package (#547011)
- Modern rpm doesn't require buildroot cleaning

* Wed Apr  2 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-9.alpha.cf
- Better check the version of less binary (#1015924)
- Drop support for old distributions prior to F-16 because we're not building
  for them anyway

* Fri Jan 10 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-8.alpha.cf
- Build with -O3 on ppc64 (private #1051078)

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 5.1.2-7.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr  9 2013 Paul Howarth <paul@city-fan.org> - 5.1.2-6.alpha.cf
- Fix manual page inconsistencies with help output (private #948533)
- Enable/fix the 'xzgrep -h' (private #850898)

* Thu Feb 21 2013 Paul Howarth <paul@city-fan.org> 5.1.2-5.alpha.cf
- Add support for ppc64p7 arch (Power7 optimized)

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 5.1.2-3.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> - 5.1.2-2.alpha.cf
- Update to 5.1.2alpha (see NEWS for details)

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 5.1.1-3.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Oct 17 2011 Paul Howarth <paul@city-fan.org> - 5.1.1-2.alpha.cf
- Update to 5.1.1alpha (#736318)
  - Support for multithreaded compression was added using the simplest method,
    which splits the input data into blocks and compresses them independently
    (other methods will be added in the future)
  - Added the options --single-stream and --block-size=SIZE to xz
  - xzdiff and xzgrep now support .lzo files if lzop is installed
    (the .tzo suffix is also recognized as a shorthand for .tar.lzo)
  - Support for short 8.3 filenames under DOS was added to xz; it is
    experimental and may change before it gets into a stable release

* Mon Jun 20 2011 Paul Howarth <paul@city-fan.org> - 5.0.3-2.0.cf
- Use bzipped tarball instead of gzipped one

* Mon May 23 2011 Paul Howarth <paul@city-fan.org> - 5.0.3-1.0.cf
- Update to 5.0.3
  - liblzma: a memory leak was fixed
  - liblzma: lzma_stream_buffer_encode() no longer creates an empty .xz Block
    if encoding an empty buffer; such an empty Block with LZMA2 data would
    trigger a bug in 5.0.1 and older
  - liblzma: validate function arguments better in a few functions; most
    importantly, specifying an unsupported integrity check to
    lzma_stream_buffer_encode() no longer creates a corrupt .xz file
  - liblzma: document that lzma_block_buffer_encode(), lzma_easy_buffer_encode(),
    lzma_stream_encoder(), and lzma_stream_buffer_encode() may return
    LZMA_UNSUPPORTED_CHECK
  - liblzma: the return values of the _memusage() functions are now documented
     better
  - Fix command name detection in xzgrep; xzegrep and xzfgrep now correctly use
    egrep and fgrep instead of grep
  - French translation was added

* Mon Apr  4 2011 Paul Howarth <paul@city-fan.org> - 5.0.2-1.0.cf
- Update to 5.0.2
  - LZMA2 decompressor now correctly accepts LZMA2 streams with no uncompressed
    data
  - "xz --suffix=.foo filename.foo" now refuses to compress the file due to it
    already having the suffix .foo
  - "xzgrep -l foo bar.xz" works now
  - Polish translation was added
- Nobody else likes macros for commands

* Wed Feb  9 2011 Paul Howarth <paul@city-fan.org> - 5.0.1-2.0.cf
- Remove URL tag from liblzma.pc if we have have pkgconfig ≤ 0.15
- Drop explicit dependency of devel package on pkgconfig if rpm can
  auto-detect the requirement

* Sat Jan 29 2011 Paul Howarth <paul@city-fan.org> - 5.0.1-1.0.cf
- Update to 5.0.1
  - xz --force now (de)compresses files that have setuid, setgid, or sticky bit
    set and files that have multiple hard links; the man page had it documented
    this way already but the code had a bug
  - gzip and bzip2 support in xzdiff was fixed
  - Portability fixes
  - Minor fix to Czech translation

* Mon Oct 25 2010 Paul Howarth <paul@city-fan.org> - 5.0.0-4.0.cf
- Update to the new upstream release, with liblzma.so.5
- Introduce compat-libs subpackage with liblzma.so.0 for compatibility with
  distributions using older releases

* Sun Oct 17 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.6.beta.212.gacbc
- Update to latest git snapshot

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.5.beta.20100401git
- Rebuild for i686 in RHEL-6 beta

* Thu Apr  1 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.4.beta.20100401git
- Sync with upstream (#578925)
- Add message translations, in libs package

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.3.beta.20091007git
- Move xz man pages to main package, leave lzma ones where they belong (#566484)

* Sat Dec 26 2009 Paul Howarth <paul@city-fan.org> - 4.999.9-0.2.beta.20091007git
- Import from Fedora

* Wed Oct 07 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.9-0.1.20091007.beta
- Sync with upstream again

* Fri Oct 02 2009 Jindrich Novy <jnovy@redhat.com> 4.999.9-0.1.20091002.beta
- Sync with upstream to generate the same archives on machines with different
  endianess

* Fri Aug 28 2009 Jindrich Novy <jnovy@redhat.com> 4.999.9-0.1.beta
- Update to 4.999.9beta

* Mon Aug 17 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8-0.10.beta.20090817git
- Sync with upstream because of #517806

* Tue Aug 04 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8-0.9.beta.20090804git
- Update to the latest GIT snapshot

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.999.8-0.8.beta
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 17 2009 Bill Nottingham <notting@redhat.com> - 4.999.8-0.7.beta
- Tweak summary
- Add %%check section (<tibbs@math.uh.edu>)

* Thu Jul 09 2009 Bill Nottingham <notting@redhat.com> - 4.999.8-0.6.beta
- Fix release versioning to match guidelines
- Fix up lzma-compat summary/description
- Tweak licensing

* Mon Jun 22 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.5
- Introduce lzma-compat subpackage

* Fri Jun 19 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.4
- Try to not to conflict with lzma

* Thu Jun 18 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.3
- Obsolete but don't provide lzma, they are largely incompatible
- Put beta to Release

* Wed Jun 17 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.2
- Obsolete old lzma
- Add Requires: pkgconfig

* Tue Jun 16 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.1
- Package XZ Utils, based on LZMA Utils packaged by Per Patrice Bouchand
